@@ -69,6 +69,7 @@ typedef struct _PhogLockscreen
 typedef struct {
   GtkWidget         *carousel;
   PhogGreetd        *greetd;
+  PhogLocksreenPos   current_pos;
 
   /* info page */
   GtkWidget         *box_info;
@@ -413,6 +414,11 @@ carousel_page_changed_cb (PhogLockscreen *self,
   gboolean osk_visible = phog_osk_manager_get_visible (osk_manager);
   g_autoptr(GError) error = NULL;
 
+  if (index == priv->current_pos)
+    return;
+
+  priv->current_pos = index;
+
   if (index == POS_OVERVIEW) {
     clear_input (self, TRUE);
     gtk_widget_set_sensitive (priv->entry_pin, FALSE);
